require 'nokogiri'
require 'open-uri'

# Oxford Dictionaries module
module Oxforddictionaries
  # Parser class
  class Parser
    attr_reader :word

    def initialize
      @word, @html, @page = '', '', nil
    end

    def exist?
      first = !(regex =~ single_match).nil?
      second = !(regex =~ plural_matches).nil?
      (first || second)
    end

    def word=(text)
      @word = text
      @html = read
      @page = Nokogiri::HTML(@html)
    end

    private

    def host
      'http://www.oxforddictionaries.com/definition/english/'
    end

    def path
      "#{host}#{word}"
    end

    def read
      open(path).read
    rescue
      nil
    end

    def single_match
      tag = @page.search('h1').first
      tag && tag.text
    end

    def plural_matches
      tag = @page.search("##{@word}").first
      tag && tag.text
    end

    def regex
      @regex ||= /.*[Dd]efinitions* of #{@word} in English:/
    end
  end
end
